@@ -11,7 +11,6 @@ library(NNS)
 library(data.table)
 require(knitr)
 require(rgl)
-require(meboot)
 
 ## ----cars, fig.width=7, fig.align='center'------------------------------------
 mpg_auto_trans = mtcars[mtcars$am==1, "mpg"]
@@ -60,5 +59,5 @@ NNS.FSD(x, y)
 #  [1] "x4" "x2" "x8" "x6"
 
 ## ----threads, echo = FALSE----------------------------------------------------
-Sys.setenv("OMP_THREAD_LIMIT" = 0)
+Sys.setenv("OMP_THREAD_LIMIT" = "")
 
